diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/sequences/templates/sequence/sql/10.0_plus/get_def.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/sequences/templates/sequence/sql/10.0_plus/get_def.sql
new file mode 100644
index 0000000..9ecb461
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/sequences/templates/sequence/sql/10.0_plus/get_def.sql
@@ -0,0 +1,11 @@
+SELECT
+    last_value,
+    seqmin AS min_value,
+    seqmax AS max_value,
+    seqstart AS start_value,
+    seqcache AS cache_value,
+    seqcycle AS is_cycled,
+    seqincrement AS increment_by,
+    is_called
+FROM pg_sequence, {{ conn|qtIdent(data.schema) }}.{{ conn|qtIdent(data.name) }}
+WHERE seqrelid = '{{ conn|qtIdent(data.schema) }}.{{ conn|qtIdent(data.name) }}'::regclass
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/sequences/templates/sequence/sql/default/update.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/sequences/templates/sequence/sql/default/update.sql
index cb1df06..cf59489 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/sequences/templates/sequence/sql/default/update.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/sequences/templates/sequence/sql/default/update.sql
@@ -11,22 +11,22 @@ ALTER SEQUENCE {{ conn|qtIdent(o_data.schema, data.name) }}
     OWNER TO {{ conn|qtIdent(data.seqowner) }};
 
 {% endif %}
-{% if data.current_value %}
+{% if data.current_value is defined %}
 {% set seqname = conn|qtIdent(o_data.schema, data.name) %}
 SELECT setval({{ seqname|qtLiteral }}, {{ data.current_value }}, true);
 
 {% endif %}
 {% set defquery = '' %}
-{% if data.increment %}
+{% if data.increment is defined %}
 {% set defquery = defquery+'\n    INCREMENT '+data.increment|string %}
 {% endif %}
-{% if data.minimum %}
+{% if data.minimum is defined %}
 {% set defquery = defquery+'\n    MINVALUE '+data.minimum|string %}
 {% endif %}
-{% if data.maximum %}
+{% if data.maximum is defined %}
 {% set defquery = defquery+'\n    MAXVALUE '+data.maximum|string %}
 {% endif %}
-{% if data.cache %}
+{% if data.cache is defined %}
 {% set defquery = defquery+'\n    CACHE '+data.cache|string %}
 {% endif %}
 {% if data.cycled == True %}
diff --git a/web/pgadmin/browser/server_groups/servers/templates/__init__.py b/web/pgadmin/browser/server_groups/servers/templates/__init__.py
deleted file mode 100644
index e69de29..0000000
diff --git a/web/pgadmin/browser/server_groups/servers/templates/connect/__init__.py b/web/pgadmin/browser/server_groups/servers/templates/connect/__init__.py
deleted file mode 100644
index e69de29..0000000
diff --git a/web/pgadmin/browser/server_groups/servers/templates/connect/sql/10.0_plus/check_recovery.sql b/web/pgadmin/browser/server_groups/servers/templates/connect/sql/10.0_plus/check_recovery.sql
new file mode 100644
index 0000000..fd27aaa
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/templates/connect/sql/10.0_plus/check_recovery.sql
@@ -0,0 +1,9 @@
+SELECT CASE WHEN usesuper
+       THEN pg_is_in_recovery()
+       ELSE FALSE
+       END as inrecovery,
+       CASE WHEN usesuper AND pg_is_in_recovery()
+       THEN pg_is_wal_replay_paused()
+       ELSE FALSE
+       END as isreplaypaused
+FROM pg_user WHERE usename=current_user
\ No newline at end of file
diff --git a/web/pgadmin/browser/server_groups/servers/templates/connect/sql/__init__.py b/web/pgadmin/browser/server_groups/servers/templates/connect/sql/__init__.py
deleted file mode 100644
index e69de29..0000000
diff --git a/web/pgadmin/browser/server_groups/servers/templates/connect/sql/tests/__init__.py b/web/pgadmin/browser/server_groups/servers/templates/connect/sql/tests/__init__.py
deleted file mode 100644
index e69de29..0000000
diff --git a/web/pgadmin/browser/server_groups/servers/templates/connect/sql/tests/test_check_recovery.py b/web/pgadmin/browser/server_groups/servers/templates/connect/sql/tests/test_check_recovery.py
deleted file mode 100644
index 954e20b..0000000
--- a/web/pgadmin/browser/server_groups/servers/templates/connect/sql/tests/test_check_recovery.py
+++ /dev/null
@@ -1,37 +0,0 @@
-import os
-
-from pgadmin.utils.route import BaseTestGenerator
-from regression.python_test_utils import test_utils
-
-
-class TestCheckRecovery(BaseTestGenerator):
-
-    versions_to_test = ["default", "9.0_plus"]
-
-    scenarios = [
-        ("Test for check recovery", dict())
-    ]
-
-    def runTest(self):
-
-        cursor = test_utils.get_db_connection(self.server['db'],
-                                              self.server['username'],
-                                              self.server['db_password'],
-                                              self.server['host'],
-                                              self.server['port']).cursor()
-
-        for version in self.versions_to_test:
-            template_file = os.path.join(os.path.dirname(__file__), "..", version, "check_recovery.sql")
-
-            cursor.execute(open(template_file, 'r').read())
-            fetch_result = cursor.fetchall()
-
-            first_row = {}
-            for index, description in enumerate(cursor.description):
-                first_row[description.name] = fetch_result[0][index]
-
-            in_recovery = first_row['inrecovery']
-            wal_paused = first_row['isreplaypaused']
-
-            self.assertEqual(False, in_recovery)
-            self.assertEqual(False, wal_paused)
diff --git a/web/pgadmin/browser/server_groups/servers/tests/test_check_recovery.py b/web/pgadmin/browser/server_groups/servers/tests/test_check_recovery.py
new file mode 100644
index 0000000..870f2a4
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/tests/test_check_recovery.py
@@ -0,0 +1,46 @@
+import os
+
+from pgadmin.utils.route import BaseTestGenerator
+from regression.python_test_utils import test_utils
+
+
+class TestCheckRecovery(BaseTestGenerator):
+
+    scenarios = [
+        ("Test for check recovery", dict())
+    ]
+
+    def runTest(self):
+
+        cursor = test_utils.get_db_connection(self.server['db'],
+                                              self.server['username'],
+                                              self.server['db_password'],
+                                              self.server['host'],
+                                              self.server['port']).cursor()
+
+        if cursor is not None and cursor.connection is not None:
+            server_version = cursor.connection.server_version
+            if server_version >= 100000:
+                version = '10.0_plus'
+            elif server_version >= 90000:
+                version = '9.0_plus'
+            else:
+                version = 'default'
+
+            template_file = os.path.join(
+                os.path.dirname(__file__), "../templates/connect/sql", version,
+                "check_recovery.sql"
+            )
+
+            cursor.execute(open(template_file, 'r').read())
+            fetch_result = cursor.fetchall()
+
+            first_row = {}
+            for index, description in enumerate(cursor.description):
+                first_row[description.name] = fetch_result[0][index]
+
+            in_recovery = first_row['inrecovery']
+            wal_paused = first_row['isreplaypaused']
+
+            self.assertEqual(False, in_recovery)
+            self.assertEqual(False, wal_paused)
diff --git a/web/pgadmin/dashboard/__init__.py b/web/pgadmin/dashboard/__init__.py
index 0a0796a..a95ba53 100644
--- a/web/pgadmin/dashboard/__init__.py
+++ b/web/pgadmin/dashboard/__init__.py
@@ -131,6 +131,22 @@ def check_precondition(f):
             PG_DEFAULT_DRIVER).connection_manager(
             kwargs['sid']
         )
+
+        # Below check handle the case where existing server is deleted
+        # by user and python server will raise exception if this check
+        # is not introduce.
+        if g.manager is None:
+            if f.__name__ in ['activity', 'prepared', 'locks', 'config']:
+                return precondition_required(
+                    gettext("Please connect to the selected server"
+                            " to view the table.")
+                )
+            else:
+                return precondition_required(
+                    gettext("Please connect to the selected server"
+                            " to view the graph.")
+                )
+
         g.conn = g.manager.connection()
 
         # If DB not connected then return error to browser
diff --git a/web/pgadmin/utils/versioned_template_loader.py b/web/pgadmin/utils/versioned_template_loader.py
index 7d2b70f..df24ab7 100644
--- a/web/pgadmin/utils/versioned_template_loader.py
+++ b/web/pgadmin/utils/versioned_template_loader.py
@@ -16,6 +16,7 @@ class VersionedTemplateLoader(DispatchingJinjaLoader):
         template_path_parts = template.split("#", 2)
 
         server_versions = (
+            {'name': "10.0_plus", 'number': 100000},
             {'name': "9.6_plus", 'number': 90600},
             {'name': "9.5_plus", 'number': 90500},
             {'name': "9.4_plus", 'number': 90400},
